Direct access wrappers for Agent class methods.
This namespace imports criterium.agent.Agent and provides Clojure functions that compile to direct field access and static method calls, avoiding reflection.
This namespace will fail to load if the Agent class is not available.
Direct access wrappers for Agent class methods. This namespace imports criterium.agent.Agent and provides Clojure functions that compile to direct field access and static method calls, avoiding reflection. This namespace will fail to load if the Agent class is not available.
(allocation-finish-marker)Call Agent.allocation_finish_marker directly.
Call Agent.allocation_finish_marker directly.
(allocation-start-marker)Call Agent.allocation_start_marker directly.
Call Agent.allocation_start_marker directly.
(method-tracing-finish-marker)Call Agent.method_tracing_finish_marker directly. Generates a method entry event that triggers completion of tracing.
Call Agent.method_tracing_finish_marker directly. Generates a method entry event that triggers completion of tracing.
(method-tracing-start-marker)Call Agent.method_tracing_start_marker directly. Generates a method entry event that triggers transition to active state.
Call Agent.method_tracing_start_marker directly. Generates a method entry event that triggers transition to active state.
(read-state)Read Agent.state field directly.
Read Agent.state field directly.
(send-command cmd)Call Agent.command directly.
Call Agent.command directly.
(set-handler handler-fn)Call Agent.set_handler directly.
Call Agent.set_handler directly.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |