Clojure only.

criterium.array.util

Utilities for defining typed array interfaces.

Provides definterface+, an extension of Clojure's definterface that supports interface inheritance via gen-interface's :extends option.

Utilities for defining typed array interfaces.

Provides `definterface+`, an extension of Clojure's `definterface` that
supports interface inheritance via `gen-interface`'s `:extends` option.
raw docstring

definterface+cljmacro

(definterface+ name & sigs)
(definterface+ name [extends...] & sigs)

Create a new Java interface, optionally extending other interfaces.

Like definterface, but accepts an optional vector of interfaces to extend as the first form after the name.

Examples: ;; Without extends (same as definterface) (definterface+ IFoo (^long bar [^double x]))

;; With single extend (definterface+ IBar [IFoo] (^double qux [^long y]))

;; With multiple extends (definterface+ IBaz [IFoo IBar] (baz []))

Create a new Java interface, optionally extending other interfaces.

Like `definterface`, but accepts an optional vector of interfaces to extend
as the first form after the name.

Examples:
  ;; Without extends (same as definterface)
  (definterface+ IFoo
    (^long bar [^double x]))

  ;; With single extend
  (definterface+ IBar [IFoo]
    (^double qux [^long y]))

  ;; With multiple extends
  (definterface+ IBaz [IFoo IBar]
    (baz []))
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries