criterium.bench.impl

Internal implementation details for criterium.bench namespace. Not intended for direct use by consumers of the library.

Internal implementation details for criterium.bench namespace.
Not intended for direct use by consumers of the library.
raw docstring

last-benchclj

(last-bench)

Retrieve the results of the last benchmark execution. Internal use only.

Retrieve the results of the last benchmark execution.
Internal use only.
sourceraw docstring

last-bench!clj

(last-bench! results)

Store the results of the last benchmark execution.

Store the results of the last benchmark execution.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries