Collection plan to control the collection of metrics from a measured.
Collection plan to control the collection of metrics from a measured.
(collect collect-plan collector measured)Collect metrics from the measured according to the collect-plan. Return a results-map.
Collect metrics from the measured according to the collect-plan. Return a results-map.
(required-stages collect-plan-id)Metrics collection stages required for the given collection-scheme
Metrics collection stages required for the given collection-scheme
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |