(limit-samples limit-time-ns
num-warmup-samples
num-measure-samples
taken-time
remaining-time
projected-time)Determine sample counts, limiting if projected time exceeds remaining time. Returns a map with :num-warmup-samples, :num-measure-samples, and when time-limited, :time-limited? true and :projected-time-ns.
Determine sample counts, limiting if projected time exceeds remaining time. Returns a map with :num-warmup-samples, :num-measure-samples, and when time-limited, :time-limited? true and :projected-time-ns.
Pipeline stages required for the given schema-type
Pipeline stages required for the given schema-type
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |