(metric-ids {:keys [stages terminator] :as _pipline-config})Return a sequence of all metrics produced by a pipeline with the given pipeline config.
Each stage can specify a :metric-id that differs from its :id. When present, :metric-id is used; otherwise :id is used.
Return a sequence of all metrics produced by a pipeline with the given pipeline config. Each stage can specify a :metric-id that differs from its :id. When present, :metric-id is used; otherwise :id is used.
(pipeline* collector-config)Build a pipeline by specifying pipeline function keywords.
Returns an updated state, adding :pipeline and :metrics keys.
Build a pipeline by specifying pipeline function keywords. Returns an updated state, adding :pipeline and :metrics keys.
(pipeline-sample-fn collector-config)Build a pipeline sample function by specifying pipeline function keywords.
Returns a function to collect a sample.
Build a pipeline sample function by specifying pipeline function keywords. Returns a function to collect a sample.
(pipeline-sample-fn* {:keys [stages terminator] :as collector-config})Build a pipeline sample function by specifying pipeline function keywords.
Returns a function to collect a sample.
Build a pipeline sample function by specifying pipeline function keywords. Returns a function to collect a sample.
(pipeline-xform-fn {:keys [stages terminator] :as _collector-config})Build a pipeline xform by specifying pipeline function keywords.
Returns an xform function.
Build a pipeline xform by specifying pipeline function keywords. Returns an xform function.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |