criterium.random.interface

Public API for the random component.

Provides pseudo-random number generation:

  • WELL RNG 1024a algorithm for high-quality uniform random doubles
  • Ziggurat algorithm for normal (Gaussian) random variates

Primary API (mutable RNGs for performance):

  • make-well-rng-1024a - Create a uniform RNG
  • next-double! - Generate next uniform random double in [0,1)
  • make-normal-rng - Create a normal/Gaussian RNG
  • next-gaussian! - Generate next standard normal variate

References:

  • WELL RNG: Improved Long-Period Generators Based on Linear Recurrences Modulo 2, F. Panneton, P. L'Ecuyer and M. Matsumoto http://www.iro.umontreal.ca/~panneton/WELLRNG.html
  • Ziggurat: An improved Ziggurat method to generate normal random samples, Doornik, 2005
Public API for the random component.

Provides pseudo-random number generation:
- WELL RNG 1024a algorithm for high-quality uniform random doubles
- Ziggurat algorithm for normal (Gaussian) random variates

Primary API (mutable RNGs for performance):
- `make-well-rng-1024a` - Create a uniform RNG
- `next-double!` - Generate next uniform random double in [0,1)
- `make-normal-rng` - Create a normal/Gaussian RNG
- `next-gaussian!` - Generate next standard normal variate

References:
- WELL RNG: Improved Long-Period Generators Based on Linear Recurrences
  Modulo 2, F. Panneton, P. L'Ecuyer and M. Matsumoto
  http://www.iro.umontreal.ca/~panneton/WELLRNG.html
- Ziggurat: An improved Ziggurat method to generate normal random samples,
  Doornik, 2005
raw docstring

make-normal-rngclj

(make-normal-rng)
(make-normal-rng uniform-rng)
(make-normal-rng uniform-rng c r v)

Create a NormalRng instance for generating standard normal variates. See criterium.random.ziggurat/make-normal-rng for full documentation.

Create a NormalRng instance for generating standard normal variates.
See `criterium.random.ziggurat/make-normal-rng` for full documentation.
sourceraw docstring

make-well-rng-1024aclj

(make-well-rng-1024a)
(make-well-rng-1024a seed)

Create a WellRng1024a instance for generating uniform random doubles. See criterium.random.well/make-well-rng-1024a for full documentation.

Create a WellRng1024a instance for generating uniform random doubles.
See `criterium.random.well/make-well-rng-1024a` for full documentation.
sourceraw docstring

next-double!clj

(next-double! rng)

Generate the next random double in [0,1), mutating the RNG state.

Generate the next random double in [0,1), mutating the RNG state.
sourceraw docstring

next-gaussian!clj

(next-gaussian! rng)

Generate the next random gaussian in N(0,1), mutating the RNG state.

Generate the next random gaussian in N(0,1), mutating the RNG state.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries