criterium.random.ziggurat

Ziggurat algorithm for generating normal random variates.

See: An improved Ziggurat method to generate normal random samples, Doornik, 2005

Ziggurat algorithm for generating normal random variates.

See: An improved Ziggurat method to generate normal random samples,
Doornik, 2005
raw docstring

make-normal-rngclj

(make-normal-rng)
(make-normal-rng uniform-rng)
(make-normal-rng uniform-rng c r v)

Create a NormalRng instance for generating standard normal variates. Returns a mutable RNG that generates doubles from N(0,1) via next-gaussian!.

Arities:

  • () - Uses default WELL RNG with standard ziggurat parameters
  • (uniform-rng) - Uses provided WellRng1024a with standard parameters
  • (uniform-rng c r v) - Uses provided RNG with custom ziggurat parameters

Standard parameters: c=128 blocks, r=3.442619855899, v=9.91256303526217e-3

See: An improved Ziggurat method to generate normal random samples, Doornik, 2005

Create a NormalRng instance for generating standard normal variates.
Returns a mutable RNG that generates doubles from N(0,1) via next-gaussian!.

Arities:
- () - Uses default WELL RNG with standard ziggurat parameters
- (uniform-rng) - Uses provided WellRng1024a with standard parameters
- (uniform-rng c r v) - Uses provided RNG with custom ziggurat parameters

Standard parameters: c=128 blocks, r=3.442619855899, v=9.91256303526217e-3

See: An improved Ziggurat method to generate normal random samples,
Doornik, 2005
sourceraw docstring

next-gaussian!clj

(next-gaussian! rng)

Generate the next random gaussian in N(0,1), mutating the RNG state. Returns a double.

Generate the next random gaussian in N(0,1), mutating the RNG state.
Returns a double.
sourceraw docstring

sqrcljmacro

(sqr x)
source

zignor-cclj

Number of blocks.

Number of blocks.
sourceraw docstring

zignor-initclj

(zignor-init c r v)

Initialise tables.

Initialise tables.
sourceraw docstring

zignor-rclj

Start of the right tail: (R * phi(R) + Pr(X>=R)) * sqrt(2pi)

Start of the right tail: (R * phi(R) + Pr(X>=R)) * sqrt(2pi)
sourceraw docstring

zignor-vclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries