criterium.sampler

Protocol and utilities for working with performance sampling state.

Provides a standard interface for components that collect and store performance metrics samples during execution.

Protocol and utilities for working with performance sampling state.

Provides a standard interface for components that collect and store
performance metrics samples during execution.
raw docstring

Samplercljprotocol

Protocol for accessing sampling state

Protocol for accessing sampling state

reset-samples!clj

(reset-samples! this)

Clear all collected samples

Clear all collected samples

samples-mapclj

(samples-map this)

Get the current samples collected

Get the current samples collected
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries