criterium.stats.sampling

Sampling utilities: sample functions, confidence intervals.

All sampling functions take mutable uniform RNGs and call next-double! to generate random values.

Sampling utilities: sample functions, confidence intervals.

All sampling functions take mutable uniform RNGs and call next-double!
to generate random values.
raw docstring

confidence-intervalclj

(confidence-interval mean variance)

Find the significance of outliers given bootstrapped mean and variance estimates. This uses the bootstrapped statistic's variance, but we should use BCa or ABC.

Find the significance of outliers given bootstrapped mean and variance
estimates. This uses the bootstrapped statistic's variance, but we should use
BCa or ABC.
sourceraw docstring

sampleclj

(sample x rng)

Sample n items with replacement from collection x. rng is a mutable uniform RNG. Returns a vector of sampled items.

Sample n items with replacement from collection x.
rng is a mutable uniform RNG.
Returns a vector of sampled items.
sourceraw docstring

sample-doublesclj

(sample-doubles arr rng)

Sample with replacement from a DoubleArray, returning a new DoubleArray. rng is a mutable uniform RNG.

Sample with replacement from a DoubleArray, returning a new DoubleArray.
rng is a mutable uniform RNG.
sourceraw docstring

sample-uniformclj

(sample-uniform n max-val rng)

Provide n samples from a uniform distribution on [0, max-val). rng is a mutable uniform RNG. Returns a vector of n doubles.

Provide n samples from a uniform distribution on [0, max-val).
rng is a mutable uniform RNG.
Returns a vector of n doubles.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries