criterium.stats.t-digest.scale

Scale functions for t-digest algorithm. These control how cluster sizes are determined and affect accuracy in different ways.

Scale functions for t-digest algorithm.
These control how cluster sizes are determined and affect accuracy in different ways.
raw docstring

boundclj

(bound x)
source

finite?clj

(finite? x)
source

kclj

(k scale q normalizer)
(k scale q compression n)

Convert quantile q to k-scale value using normalized compression.

Convert quantile q to k-scale value using normalized compression.
sourceraw docstring

k0clj

Scale function that generates uniform cluster sizes. Used mainly for testing and comparison.

Scale function that generates uniform cluster sizes.
Used mainly for testing and comparison.
sourceraw docstring

k1clj

Scale function that generates cluster sizes proportional to sqrt(q*(1-q)). Gives constant relative accuracy if accuracy is proportional to squared cluster size.

Scale function that generates cluster sizes proportional to sqrt(q*(1-q)).
Gives constant relative accuracy if accuracy is proportional to
squared cluster size.
sourceraw docstring

k1-k-limit-f-lowclj

source

k1-q-limit-f-highclj

source

k1-q-limit-highclj

source

k1-q-limit-lowclj

source

k1-x-limit-highclj

source

k1-x-limit-lowclj

source

k2clj

Scale function that generates cluster sizes proportional to q*(1-q). Makes tail error bounds tighter than K1.

Scale function that generates cluster sizes proportional to q*(1-q).
Makes tail error bounds tighter than K1.
sourceraw docstring

limitclj

(limit x low high)
source

max-sizeclj

(max-size scale q normalizer)
(max-size scale q compression n)

Maximum allowed cluster size at quantile q using normalized compression.

Maximum allowed cluster size at quantile q using normalized compression.
sourceraw docstring

normalizerclj

(normalizer scale compression n)
source

qclj

(q scale k normalizer)
(q scale k compression n)

Convert k-scale value back to quantile q using normalized compression.

Convert k-scale value back to quantile q using normalized compression.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries