criterium.util.blackhole

Blackhole wrapper for preventing dead code elimination. Delegates to criterium.blackhole.

Blackhole wrapper for preventing dead code elimination.
Delegates to criterium.blackhole.
raw docstring

criterium.util.bootstrap

Bootstrap statistics for criterium.

Core bootstrap algorithms are provided by criterium.stats.bootstrap. This namespace provides criterium-specific integration with metrics and collect plans.

Bootstrap statistics for criterium.

Core bootstrap algorithms are provided by
criterium.stats.bootstrap. This namespace provides criterium-specific
integration with metrics and collect plans.
raw docstring

criterium.util.forms

Control flow macros.

This namespace delegates to criterium.utils.interface for the core implementation and is retained for backward compatibility.

Control flow macros.

This namespace delegates to criterium.utils.interface for the core
implementation and is retained for backward compatibility.
raw docstring

criterium.util.invariant

Assertion macros inspired by truss.

This namespace delegates to criterium.utils.interface for the core implementation and is retained for backward compatibility.

Assertion macros inspired by truss.

This namespace delegates to criterium.utils.interface for the core
implementation and is retained for backward compatibility.
raw docstring

criterium.util.t-digest

Re-exports t-digest functionality from stats component for backward compatibility.

Re-exports t-digest functionality from stats component for backward
compatibility.
raw docstring

criterium.util.t-digest.scale

Re-exports scale functions from stats component for backward compatibility.

Re-exports scale functions from stats component for backward compatibility.
raw docstring

criterium.utils.interface

Public API for the utils component.

Provides generic utilities including:

  • Assertion macros (have, have?)
  • Control flow macros (cond*)
  • Math utilities (sqr, sqrd, cubed, trunc)
  • Collection utilities (update-vals, filter-map, deep-merge)
  • Tree walking (walk, postwalk)
  • Debugging (spy, report)
Public API for the utils component.

Provides generic utilities including:
- Assertion macros (have, have?)
- Control flow macros (cond*)
- Math utilities (sqr, sqrd, cubed, trunc)
- Collection utilities (update-vals, filter-map, deep-merge)
- Tree walking (walk, postwalk)
- Debugging (spy, report)
raw docstring

criterium.utils.invariant

Assertion macros inspired by truss.

Assertion macros inspired by truss.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries