Clojure only.

criterium.util.blackhole

Blackhole wrapper for preventing dead code elimination. Delegates to criterium.blackhole.

Blackhole wrapper for preventing dead code elimination.
Delegates to criterium.blackhole.
raw docstring

consumecljmacro

(consume x)

Consume a value to prevent dead code elimination.

Consume a value to prevent dead code elimination.
sourceraw docstring

evaporateclj

(evaporate)

Evaporate the blackhole, releasing any references it may contain.

Evaporate the blackhole, releasing any references it may contain.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries