criterium.util.format

Metric formatters

Metric formatters
raw docstring

format-countclj

(format-count [k v])
source

format-metriccljmultimethod

source

format-scaledclj

(format-scaled value scale)
(format-scaled value scale unit)
source

format-valueclj

(format-value dimension value)
(format-value dimension value opts)

Format in an appropriate unit and precision for the scale.

Format in an appropriate unit and precision for the scale.
sourceraw docstring

format-value*cljmultimethod

Format value to 3 significant figures in an appropriate unit for the scale.

Format value to 3 significant figures in an appropriate unit for the scale.
sourceraw docstring

ONE-GBclj

source

ONE-KBclj

source

ONE-MBclj

source

roundclj

(round n sig-figs)

Round number to specified significant figures.

Parameters: n - Number to round sig-figs - Number of significant figures to keep

Returns: Number rounded to specified significant figures

Round number to specified significant figures.

Parameters:
  n - Number to round
  sig-figs - Number of significant figures to keep

Returns:
  Number rounded to specified significant figures
sourceraw docstring

scalecljmultimethod

Scale value with given dimensions keyword. Return a [scale units] tuple. scale is a multiplicative factor. units is a string.

Scale value with given dimensions keyword.
Return a [scale units] tuple.
scale is a multiplicative factor. units is a string.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries