Control flow macros.
This namespace delegates to criterium.utils.interface for the core implementation and is retained for backward compatibility.
Control flow macros. This namespace delegates to criterium.utils.interface for the core implementation and is retained for backward compatibility.
(cond* & clauses)A cond variant that allows :let bindings visible to subsequent clauses.
Example: (cond* (foo?) (handle-foo) :let [a 5] (> a 3) (handle-big a) :let [b (+ a 1)] (bar? b) (handle-bar b) :else (default-handler a b))
A cond variant that allows :let bindings visible to subsequent clauses.
Example:
(cond*
(foo?) (handle-foo)
:let [a 5]
(> a 3) (handle-big a)
:let [b (+ a 1)]
(bar? b) (handle-bar b)
:else (default-handler a b))cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |