criterium.utils.helpers

Generic utility functions.

Generic utility functions.
raw docstring

assoc-tagclj

(assoc-tag sym t)

Associate a type tag to a symbol's metadata.

Associate a type tag to a symbol's metadata.
sourceraw docstring

cubedclj

(cubed x)

Cube of argument

Cube of argument
sourceraw docstring

deep-mergeclj

(deep-merge & ms)

Merge maps recursively.

Merge maps recursively.
sourceraw docstring

filter-mapclj

(filter-map pred m)

Filter map entries based on a predicate applied to values.

Return a new map containing only the entries where (pred value) returns true.

Filter map entries based on a predicate applied to values.

Return a new map containing only the entries where (pred value)
returns true.
sourceraw docstring

postwalkclj

(postwalk f form)

Performs a depth-first, post-order traversal of form. Calls f on each sub-form, uses f's return value in place of the original. Recognizes all Clojure data structures. Consumes seqs as with doall.

Performs a depth-first, post-order traversal of form.  Calls f on
each sub-form, uses f's return value in place of the original.
Recognizes all Clojure data structures. Consumes seqs as with doall.
sourceraw docstring

provide-update-valscljmacro

(provide-update-vals)
source

reduce-double-vectorclj

(reduce-double-vector f init v)

Reduce a double primitive value over a vector.

Reduce a double primitive value over a vector.
sourceraw docstring

reportclj

(report format-string & values)

Print format output

Print format output
sourceraw docstring

spyclj

(spy msg x)

Debug helper: print message and value, return value.

Debug helper: print message and value, return value.
sourceraw docstring

sqrcljmacro

(sqr x)

Square of argument

Square of argument
sourceraw docstring

sqrdclj

(sqrd x)

Square of argument

Square of argument
sourceraw docstring

truncclj

(trunc x)

Round towards zero to an integeral value.

Round towards zero to an integeral value.
sourceraw docstring

update-valsclj

(update-vals m f)

m f => {k (f v) ...}

Given a map m and a function f of 1-argument, returns a new map where the keys of m are mapped to result of applying f to the corresponding values of m.

m f => {k (f v) ...}

Given a map m and a function f of 1-argument, returns a new map where
the keys of m are mapped to result of applying f to the corresponding
values of m.
sourceraw docstring

update-vals-implclj

source

walkclj

(walk inner outer form)

Traverses form, an arbitrary data structure. inner and outer are functions. Applies inner to each element of form, building up a data structure of the same type, then applies outer to the result. Recognizes all Clojure data structures. Consumes seqs as with doall.

Traverses form, an arbitrary data structure.  inner and outer are
functions.  Applies inner to each element of form, building up a
data structure of the same type, then applies outer to the result.
Recognizes all Clojure data structures. Consumes seqs as with doall.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries