criterium.viewer.common.domain.comparison

Domain comparison data preparation functions.

Provides functions to prepare domain-comparison data for various chart types including box plots, bar charts, and line charts, as well as table rendering.

Domain comparison data preparation functions.

Provides functions to prepare domain-comparison data for various chart types
including box plots, bar charts, and line charts, as well as table rendering.
raw docstring

criterium.viewer.common.domain.detection

Domain shape detection predicates for visualization strategy selection.

Provides functions to analyze the structure of domain extract and comparison data to determine the appropriate visualization strategy (box plot, line chart, or table).

Domain shape detection predicates for visualization strategy selection.

Provides functions to analyze the structure of domain extract and
comparison data to determine the appropriate visualization
strategy (box plot, line chart, or table).
raw docstring

criterium.viewer.common.domain.extract

Domain extract table preparation functions.

Provides functions to prepare domain-extract data for table rendering, including transposed tables for single-point multi-impl scenarios and grouped data tables.

Domain extract table preparation functions.

Provides functions to prepare domain-extract data for table rendering,
including transposed tables for single-point multi-impl scenarios and
grouped data tables.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries