criterium.viewer.common.shape

Shape statistics view helpers.

Provides functions for formatting and classifying shape statistics (skewness, kurtosis, CV) from bootstrap results.

Shape statistics view helpers.

Provides functions for formatting and classifying shape statistics
(skewness, kurtosis, CV) from bootstrap results.
raw docstring

cv-labelsclj

Human-readable labels for coefficient of variation classification keywords.

Human-readable labels for coefficient of variation classification keywords.
sourceraw docstring

format-classificationclj

(format-classification classification)

Format a classification keyword for display. Returns the human-readable label from the appropriate label map, or the keyword's name if not found.

Format a classification keyword for display.
Returns the human-readable label from the appropriate label map, or
the keyword's name if not found.
sourceraw docstring

kurtosis-labelsclj

Human-readable labels for kurtosis classification keywords.

Human-readable labels for kurtosis classification keywords.
sourceraw docstring

shape-stats-dataclj

(shape-stats-data metric-configs bootstrap-data)

Extract and format bootstrap shape statistics (skewness, kurtosis, CV).

Returns a vector of maps with :metric :skewness :kurtosis :cv and classification info.

Extract and format bootstrap shape statistics (skewness, kurtosis, CV).

Returns a vector of maps with :metric :skewness :kurtosis :cv and
classification info.
sourceraw docstring

skewness-labelsclj

Human-readable labels for skewness classification keywords.

Human-readable labels for skewness classification keywords.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries