Internal implementation details for criterium.bench namespace. Not intended for direct use by consumers of the library.
Internal implementation details for criterium.bench namespace. Not intended for direct use by consumers of the library.
(last-bench)Retrieve the results of the last benchmark execution. Internal use only.
Retrieve the results of the last benchmark execution. Internal use only.
(last-bench! results)Store the results of the last benchmark execution.
Store the results of the last benchmark execution.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |