A pipeline function takes a sample, a measured state, and a measured, calls the next pipeline function and returns an updated sample state. It is usually called via the execute function.
A pipeline function can be composed with other pipeline functions and a pipeline terminal function, which is responsible for actually calling the measured.
Each pipeline function collects one or metrics around the measured's invocation.
A pipeline function takes a sample, a measured state, and a measured, calls the next pipeline function and returns an updated sample state. It is usually called via the execute function. A pipeline function can be composed with other pipeline functions and a pipeline terminal function, which is responsible for actually calling the measured. Each pipeline function collects one or metrics around the measured's invocation.
Elapsed time collector that does not retain expression return values. Useful for benchmarking functions that return large data structures.
Produces :elapsed-time metric (same as elapsed-time collector).
Elapsed time collector that does not retain expression return values. Useful for benchmarking functions that return large data structures. Produces :elapsed-time metric (same as elapsed-time collector).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |