Ziggurat algorithm for generating normal random variates.
See: An improved Ziggurat method to generate normal random samples, Doornik, 2005
Ziggurat algorithm for generating normal random variates. See: An improved Ziggurat method to generate normal random samples, Doornik, 2005
(make-normal-rng)(make-normal-rng uniform-rng)(make-normal-rng uniform-rng c r v)Create a NormalRng instance for generating standard normal variates. Returns a mutable RNG that generates doubles from N(0,1) via next-gaussian!.
Arities:
Standard parameters: c=128 blocks, r=3.442619855899, v=9.91256303526217e-3
See: An improved Ziggurat method to generate normal random samples, Doornik, 2005
Create a NormalRng instance for generating standard normal variates. Returns a mutable RNG that generates doubles from N(0,1) via next-gaussian!. Arities: - () - Uses default WELL RNG with standard ziggurat parameters - (uniform-rng) - Uses provided WellRng1024a with standard parameters - (uniform-rng c r v) - Uses provided RNG with custom ziggurat parameters Standard parameters: c=128 blocks, r=3.442619855899, v=9.91256303526217e-3 See: An improved Ziggurat method to generate normal random samples, Doornik, 2005
(next-gaussian! rng)Generate the next random gaussian in N(0,1), mutating the RNG state. Returns a double.
Generate the next random gaussian in N(0,1), mutating the RNG state. Returns a double.
Start of the right tail: (R * phi(R) + Pr(X>=R)) * sqrt(2pi)
Start of the right tail: (R * phi(R) + Pr(X>=R)) * sqrt(2pi)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |