Metric formatters
Metric formatters
(format-value dimension value)(format-value dimension value opts)Format in an appropriate unit and precision for the scale.
Format in an appropriate unit and precision for the scale.
Format value to 3 significant figures in an appropriate unit for the scale.
Format value to 3 significant figures in an appropriate unit for the scale.
(round n sig-figs)Round number to specified significant figures.
Parameters: n - Number to round sig-figs - Number of significant figures to keep
Returns: Number rounded to specified significant figures
Round number to specified significant figures. Parameters: n - Number to round sig-figs - Number of significant figures to keep Returns: Number rounded to specified significant figures
Scale value with given dimensions keyword. Return a [scale units] tuple. scale is a multiplicative factor. units is a string.
Scale value with given dimensions keyword. Return a [scale units] tuple. scale is a multiplicative factor. units is a string.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |